@@ -762,6 +762,7 @@ tlds = ['xn\\-\\-vermgensberatung\\-pwb',
  'miami',
  'money',
  'movie',
+ 'music',
  'nadex',
  'nexus',
  'nikon',
@@ -942,6 +943,7 @@ tlds = ['xn\\-\\-vermgensberatung\\-pwb',
  'jobs',
  'jprs',
  'kddi',
+ 'kids',
  'kiwi',
  'kpmg',
  'kred',
