@@ -7,8 +7,19 @@ class iffs(ConditionalUnit):
     """
     Filter incoming chunks depending on whether they contain a given binary substring.
     """
-    def __init__(self, needle: Arg(help='the string to search for'), negate=False, temporary=False):
-        super().__init__(negate=negate, temporary=temporary, needle=needle)
+    def __init__(
+        self,
+        needle: Arg(help='the string to search for'),
+        negate=False,
+        backup=False,
+        single=False,
+    ):
+        super().__init__(
+            needle=needle,
+            negate=negate,
+            backup=backup,
+            single=single,
+        )
 
     def match(self, chunk):
         return self.args.needle in chunk
